#' @name SoaresEx7.6
#' @title  Pressão sanguínea sistólica de 35 indivíduos.
#' @description 35 pacientes com doença arterial coronariana, de idade 
#'     entre 35 e 75 anos, foram submetidos a teste ergométrico (Miller 
#'     et al., 1990). Os estudos realizaram-se em bicicleta ergométrica, 
#'     com os exercícios continuando até angina ou fadiga que requeresse 
#'     a suspensão da atividade. Os dados apresentados referem-se a 
#'     pressão sanguíneamsistólica em mmHg dos indivíduos em repouso e 
#'     no pico do exercício.
#' @format Um \code{data.frame} com 70 observações e 2 variáveis.
#'
#' \describe{
#'
#' \item{\code{ps}}{Pressão sanguínea sistólica em mmHg dos indivíduos 
#'     em repouso e no pico do exercício.}
#'
#' \item{\code{exp}}{Variável explicativa com os valores obtidos.}
#'
#' }
#' @keywords AAS
#' @source SOARES; SIQUEIRA, (2002), Ex.7.6, pg.259.
#' @references MILLER, P. F., SHEPS, D. S., BRAGDON, E. E. et al. 
#'     Aging and pain perception in ischemic heart disease. American 
#'     Heart Journal, v.120, p.22-30, 1990.
#' @examples
#' 
#' library(lattice)
#' data(SoaresEx7.6)
#' SoaresEx7.6$n <- seq(1:35)
#' xyplot(exp~n|ps, data = SoaresEx7.6, 
#'     type = c('g', 'b'),
#'     main = 'Pressão sanguínea sistólica de 35 indivíduos',
#'     xlab = 'Pacientes que participaram do estudo', 
#'     ylab = 'Pressão sanguínea em mmHg') 
#' 
#' 
#' 
#'
NULL
