#' @name SoaresTb7.2
#' @title Pressão ocular de pacientes em uso de placebo e timolol.
#' @description Em estudo realizado no Hospital São Geraldo da UFMG,
#'     Cronemberger e Calixto (1992) estudaram a capacidade de redução 
#'     da pressão intraocular das drogas timolol, betaxolol e 
#'     levobunolol. Para isto, medicaram 10 pacientes com as três 
#'     drogas e compararam os resultados com aqueles obtidos quando os 
#'     pacientes receberam um placebo. As medidas da pressão 
#'     intraocular, expressas em mmHg, obtida às 6 horas da manhã com os
#'     pacientes usando timolol e placebo referem-se aos dados.
#' @format Um \code{data.frame} com 10 observações e 2 variáveis.
#'
#' \describe{
#'
#' \item{\code{placebo}}{Variável utlizada no estudo.}
#'
#' \item{\code{timolol}}{Fármaco usado no estudo.}
#'
#' }
#' @keywords AAS
#' @source SOARES; SIQUEIRA, (2002), Tb.7.2, pg.242.
#' @references CRONEMBERGER, F., CALIXTO, N., SOARES, J. F. Estudo 
#'     comparativo do efeito do timolol, betaxolol e levobunolol sobre a 
#'     curva diária de pacientes glaucomatosos. Arquivos Brasileiros de 
#'     Oftamologia, v.55, p.233-7, 1992.
#' @examples
#' 
#' library(lattice)
#' data(SoaresTb7.2)
#' 
#' par(mfrow = c(1, 2))
#' hist(SoaresTb7.2$placebo,
#'      labels = TRUE,
#'      main = paste(''),
#'      col = "darkolivegreen1",
#'      ylab = "Frequência",
#'      xlab = "Pressão ocular de pacientes em uso de placebo")
#'      
#' rug(SoaresTb7.2$placebo)
#' 
#' hist(SoaresTb7.2$timolol,
#'      labels = TRUE,
#'      col = "darkolivegreen1",
#'      main = paste(''),
#'      ylab = "Frequência",
#'      xlab = "Pressão ocular de pacientes em uso de timolol")
#'      
#' rug(SoaresTb7.2$timolol)
#' title("Pressão ocular de pacientes em uso de placebo e timolol", 
#'     outer = TRUE)
#'      
#'
#' 
#' 
#' 
NULL


