#' @name SoaresTb7.6
#' @title Distribuição de casos e controles segundo a amamentação. 
#' @description Para verificar se o fato de ter sido amamentado pela mãe
#'     é um fator de proteção para o câncer de mama, Freudenheim et al. 
#'     (1994) realizaram estudo do tipo caso-controle nos condados de 
#'     Erie e Niágara situadas na parte oeste do estado de NOva York 
#'     (EUA). As pacientes tomadas como controle foram escolhidas na 
#'     população da região, não havendo emparelhamento.
#' @format Um \code{data.frame} com 4 observações e 3 variáveis.
#'
#' \describe{
#'
#' \item{\code{grupo}}{Grupos do estudo.}
#'
#' \item{\code{amt}}{Amamentação presente ou não presente.}
#'
#' \item{\code{exp}}{Variável esplicativa com os valores obtidos.}
#' }
#' @keywords AAS
#' @source SOARES; SIQUEIRA, (2002), Tb.7.6, pg.249.
#' @references FREUDENHEIM, J. L., MARSHALL, J. R. GRAHAN, S. et. al. 
#'     Exposure to breastmilk in infancy and the risk of breast cancer. 
#'     Epidemiology, v.5, n.3, p.324-31, 1994.
#' @examples
#' 
#' library(lattice)
#' data(SoaresTb7.6)
#' 
#' dados <- xtabs(exp ~ grupo + amt, data = SoaresTb7.6)
#' barchart(dados, horizontal = FALSE, 
#'     stack = FALSE,
#'     scales = list(x = list(labels = c("Casos","Controles"))),
#'     ylab = "Frequência",
#'     xlab = "Grupos",
#'     main = "Distribuição de casos e controles segundo a amamentação",
#'     auto.key = list(corner = c(0.05, 0.95), 
#'     text = c("Não", 
#'     'Sim')))
#' 
#'
NULL
